commit-gnuradio
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Commit-gnuradio] [gnuradio] 03/46: zeromq: Initial conversion of includ


From: git
Subject: [Commit-gnuradio] [gnuradio] 03/46: zeromq: Initial conversion of include/gnuradio/zeromq files
Date: Fri, 16 May 2014 19:37:12 +0000 (UTC)

This is an automated email from the git hooks/post-receive script.

jcorgan pushed a commit to branch master
in repository gnuradio.

commit 922f29c4d8d81ce76aaebda65ce5c7a797310c46
Author: Johnathan Corgan <address@hidden>
Date:   Fri Dec 6 19:53:15 2013 -0800

    zeromq: Initial conversion of include/gnuradio/zeromq files
---
 gr-zeromq/CMakeLists.txt                           |  2 +-
 .../{zmqblocks => gnuradio/zeromq}/CMakeLists.txt  | 25 ++++++++-------
 .../include/{zmqblocks => gnuradio/zeromq}/api.h   | 16 +++++-----
 .../{zmqblocks => gnuradio/zeromq}/sink_pubsub.h   | 30 +++++++++---------
 .../{zmqblocks => gnuradio/zeromq}/sink_pushpull.h | 33 +++++++++----------
 .../{zmqblocks => gnuradio/zeromq}/sink_reqrep.h   | 37 ++++++++++------------
 .../zeromq}/sink_reqrep_nopoll.h                   | 37 ++++++++++------------
 .../zeromq}/source_pushpull.h                      | 33 +++++++++----------
 .../zeromq}/source_pushpull_feedback.h             | 30 +++++++++---------
 .../{zmqblocks => gnuradio/zeromq}/source_reqrep.h | 35 ++++++++++----------
 .../zeromq}/source_reqrep_nopoll.h                 | 33 +++++++++----------
 11 files changed, 147 insertions(+), 164 deletions(-)

diff --git a/gr-zeromq/CMakeLists.txt b/gr-zeromq/CMakeLists.txt
index d664dc4..7ef24b8 100644
--- a/gr-zeromq/CMakeLists.txt
+++ b/gr-zeromq/CMakeLists.txt
@@ -85,7 +85,7 @@ CPACK_COMPONENT("zeromq_swig"
 ########################################################################
 # Add subdirectories
 ########################################################################
-#add_subdirectory(include/gnuradio/zeromq)
+add_subdirectory(include/gnuradio/zeromq)
 #add_subdirectory(lib)
 #if(ENABLE_PYTHON)
 #    add_subdirectory(swig)
diff --git a/gr-zeromq/include/zmqblocks/CMakeLists.txt 
b/gr-zeromq/include/gnuradio/zeromq/CMakeLists.txt
similarity index 73%
rename from gr-zeromq/include/zmqblocks/CMakeLists.txt
rename to gr-zeromq/include/gnuradio/zeromq/CMakeLists.txt
index 9c72e6d..c23b9d6 100644
--- a/gr-zeromq/include/zmqblocks/CMakeLists.txt
+++ b/gr-zeromq/include/gnuradio/zeromq/CMakeLists.txt
@@ -1,4 +1,4 @@
-# Copyright 2011,2012 Free Software Foundation, Inc.
+# Copyright 2013 Free Software Foundation, Inc.
 #
 # This file is part of GNU Radio
 #
@@ -18,17 +18,18 @@
 # Boston, MA 02110-1301, USA.
 
 ########################################################################
-# Install public header files
+# Install header files
 ########################################################################
 install(FILES
-    api.h
-    sink_reqrep.h
-    source_reqrep.h
-    sink_reqrep_nopoll.h
-    source_reqrep_nopoll.h
-    sink_pushpull.h
-    source_pushpull.h
-    source_pushpull_feedback.h
-    sink_pubsub.h
-    DESTINATION include/zmqblocks
+  api.h
+  sink_pubsub.h
+  sink_pushpull.h
+  sink_reqrep.h
+  sink_reqrep_nopoll.h
+  source_pushpull_feedback.h
+  source_pushpull.h
+  source_reqrep.h
+  source_reqrep_nopoll.h
+  DESTINATION ${GR_INCLUDE_DIR}/gnuradio/zeromq
+  COMPONENT "zeromq_devel"
 )
diff --git a/gr-zeromq/include/zmqblocks/api.h 
b/gr-zeromq/include/gnuradio/zeromq/api.h
similarity index 71%
rename from gr-zeromq/include/zmqblocks/api.h
rename to gr-zeromq/include/gnuradio/zeromq/api.h
index 246b7a6..82d022f 100644
--- a/gr-zeromq/include/zmqblocks/api.h
+++ b/gr-zeromq/include/gnuradio/zeromq/api.h
@@ -1,7 +1,7 @@
 /*
- * Copyright 2011 Free Software Foundation, Inc.
+ * Copyright 2013 Free Software Foundation, Inc.
  *
- * This file is part of GNU Radio
+ * This file is part of GNU Radio.
  *
  * GNU Radio is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,15 +19,15 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef INCLUDED_ZMQBLOCKS_API_H
-#define INCLUDED_ZMQBLOCKS_API_H
+#ifndef INCLUDED_ZEROMQ_API_H
+#define INCLUDED_ZEROMQ_API_H
 
 #include <gnuradio/attributes.h>
 
-#ifdef gnuradio_zmqblocks_EXPORTS
-#  define ZMQBLOCKS_API __GR_ATTR_EXPORT
+#ifdef gnuradio_zeromq_EXPORTS
+#  define ZEROMQ_API __GR_ATTR_EXPORT
 #else
-#  define ZMQBLOCKS_API __GR_ATTR_IMPORT
+#  define ZEROMQ_API __GR_ATTR_IMPORT
 #endif
 
-#endif /* INCLUDED_ZMQBLOCKS_API_H */
+#endif /* INCLUDED_ZEROMQ_API_H */
diff --git a/gr-zeromq/include/zmqblocks/source_pushpull_feedback.h 
b/gr-zeromq/include/gnuradio/zeromq/source_pushpull_feedback.h
similarity index 61%
rename from gr-zeromq/include/zmqblocks/source_pushpull_feedback.h
rename to gr-zeromq/include/gnuradio/zeromq/source_pushpull_feedback.h
index 7fc5965..2bcfe7b 100644
--- a/gr-zeromq/include/zmqblocks/source_pushpull_feedback.h
+++ b/gr-zeromq/include/gnuradio/zeromq/source_pushpull_feedback.h
@@ -1,6 +1,8 @@
 /* -*- c++ -*- */
 /* 
- * Copyright 2013 <+YOU OR YOUR COMPANY+>.
+ * Copyright 2013 Free Software Foundation, Inc.
+ *
+ * This file is part of GNU Radio.
  * 
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,39 +20,37 @@
  * Boston, MA 02110-1301, USA.
  */
 
+#ifndef INCLUDED_ZEROMQ_SOURCE_PUSHPULL_FEEDBACK_H
+#define INCLUDED_ZEROMQ_SOURCE_PUSHPULL_FEEDBACK_H
 
-#ifndef INCLUDED_ZMQBLOCKS_SOURCE_PUSHPULL_FEEDBACK_H
-#define INCLUDED_ZMQBLOCKS_SOURCE_PUSHPULL_FEEDBACK_H
-
-#include <zmqblocks/api.h>
+#include <gnuradio/zeromq/api.h>
 #include <gnuradio/sync_block.h>
 
 namespace gr {
-  namespace zmqblocks {
+  namespace zeromq {
 
     /*!
      * \brief <+description of block+>
-     * \ingroup zmqblocks
+     * \ingroup zeromq
      *
      */
-    class ZMQBLOCKS_API source_pushpull_feedback : virtual public 
gr::sync_block
+    class ZEROMQ_API source_pushpull_feedback : virtual public gr::sync_block
     {
-     public:
+    public:
       typedef boost::shared_ptr<source_pushpull_feedback> sptr;
 
       /*!
-       * \brief Return a shared_ptr to a new instance of 
zmqblocks::source_pushpull_feedback.
+       * \brief Return a shared_ptr to a new instance of 
zeromq::source_pushpull_feedback.
        *
-       * To avoid accidental use of raw pointers, 
zmqblocks::source_pushpull_feedback's
+       * To avoid accidental use of raw pointers, 
zeromq::source_pushpull_feedback's
        * constructor is in a private implementation
-       * class. zmqblocks::source_pushpull_feedback::make is the public 
interface for
+       * class. zeromq::source_pushpull_feedback::make is the public interface 
for
        * creating new instances.
        */
       static sptr make(size_t itemsize, char *address);
     };
 
-  } // namespace zmqblocks
+  } // namespace zeromq
 } // namespace gr
 
-#endif /* INCLUDED_ZMQBLOCKS_SOURCE_PUSHPULL_FEEDBACK_H */
-
+#endif /* INCLUDED_ZEROMQ_SOURCE_PUSHPULL_FEEDBACK_H */
diff --git a/gr-zeromq/include/zmqblocks/source_reqrep_nopoll.h 
b/gr-zeromq/include/gnuradio/zeromq/source_reqrep_nopoll.h
similarity index 59%
rename from gr-zeromq/include/zmqblocks/source_reqrep_nopoll.h
rename to gr-zeromq/include/gnuradio/zeromq/source_reqrep_nopoll.h
index fd22a0f..21da57e 100644
--- a/gr-zeromq/include/zmqblocks/source_reqrep_nopoll.h
+++ b/gr-zeromq/include/gnuradio/zeromq/source_reqrep_nopoll.h
@@ -1,9 +1,8 @@
 /* -*- c++ -*- */
 /* 
- * Copyright 2013 Institute for Theoretical Information Technology,
- *                RWTH Aachen University
- * 
- * Authors: Johannes Schmitz <address@hidden>
+ * Copyright 2013 Free Software Foundation, Inc.
+ *
+ * This file is part of GNU Radio.
  * 
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,39 +20,37 @@
  * Boston, MA 02110-1301, USA.
  */
 
+#ifndef INCLUDED_ZEROMQ_SOURCE_REQREP_NOPOLL_H
+#define INCLUDED_ZEROMQ_SOURCE_REQREP_NOPOLL_H
 
-#ifndef INCLUDED_ZMQBLOCKS_SOURCE_REQREP_NOPOLL_H
-#define INCLUDED_ZMQBLOCKS_SOURCE_REQREP_NOPOLL_H
-
-#include <zmqblocks/api.h>
+#include <gnuradio/zeromq/api.h>
 #include <gnuradio/sync_block.h>
 
 namespace gr {
-  namespace zmqblocks {
+  namespace zeromq {
 
     /*!
      * \brief <+description of block+>
-     * \ingroup zmqblocks
+     * \ingroup zeromq
      *
      */
-    class ZMQBLOCKS_API source_reqrep_nopoll : virtual public gr::sync_block
+    class ZEROMQ_API source_reqrep_nopoll : virtual public gr::sync_block
     {
-     public:
+    public:
       typedef boost::shared_ptr<source_reqrep_nopoll> sptr;
 
       /*!
-       * \brief Return a shared_ptr to a new instance of 
zmqblocks::source_reqrep_nopoll.
+       * \brief Return a shared_ptr to a new instance of 
zeromq::source_reqrep_nopoll.
        *
-       * To avoid accidental use of raw pointers, 
zmqblocks::source_reqrep_nopoll's
+       * To avoid accidental use of raw pointers, 
zeromq::source_reqrep_nopoll's
        * constructor is in a private implementation
-       * class. zmqblocks::source_reqrep_nopoll::make is the public interface 
for
+       * class. zeromq::source_reqrep_nopoll::make is the public interface for
        * creating new instances.
        */
       static sptr make(size_t itemsize, char *address);
     };
 
-  } // namespace zmqblocks
+  } // namespace zeromq
 } // namespace gr
 
-#endif /* INCLUDED_ZMQBLOCKS_SOURCE_REQREP_NOPOLL_H */
-
+#endif /* INCLUDED_ZEROMQ_SOURCE_REQREP_NOPOLL_H */



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/gr-zeromq/include/zmqblocks/sink_pubsub.h 
b/gr-zeromq/include/gnuradio/zeromq/sink_pubsub.h
similarity index 64%
rename from gr-zeromq/include/zmqblocks/sink_pubsub.h
rename to gr-zeromq/include/gnuradio/zeromq/sink_pubsub.h
index f55d07b..bba8836 100644
--- a/gr-zeromq/include/zmqblocks/sink_pubsub.h
+++ b/gr-zeromq/include/gnuradio/zeromq/sink_pubsub.h
@@ -1,7 +1,9 @@
 /* -*- c++ -*- */
 /* 
- * Copyright 2013 <+YOU OR YOUR COMPANY+>.
+ * Copyright 2013 Free Software Foundation, Inc.
  * 
+ * This file is part of GNU Radio.
+ *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3, or (at your option)
@@ -18,39 +20,37 @@
  * Boston, MA 02110-1301, USA.
  */
 
+#ifndef INCLUDED_ZEROMQ_SINK_PUBSUB_H
+#define INCLUDED_ZEROMQ_SINK_PUBSUB_H
 
-#ifndef INCLUDED_ZMQBLOCKS_SINK_PUBSUB_H
-#define INCLUDED_ZMQBLOCKS_SINK_PUBSUB_H
-
-#include <zmqblocks/api.h>
+#include <gnuradio/zeromq/api.h>
 #include <gnuradio/sync_block.h>
 
 namespace gr {
-  namespace zmqblocks {
+  namespace zeromq {
 
     /*!
      * \brief <+description of block+>
-     * \ingroup zmqblocks
+     * \ingroup zeromq
      *
      */
-    class ZMQBLOCKS_API sink_pubsub : virtual public gr::sync_block
+    class ZEROMQ_API sink_pubsub : virtual public gr::sync_block
     {
-     public:
+    public:
       typedef boost::shared_ptr<sink_pubsub> sptr;
 
       /*!
-       * \brief Return a shared_ptr to a new instance of 
zmqblocks::sink_pubsub.
+       * \brief Return a shared_ptr to a new instance of zeromq::sink_pubsub.
        *
        * To avoid accidental use of raw pointers, zmqblocks::sink_pubsub's
        * constructor is in a private implementation
        * class. zmqblocks::sink_pubsub::make is the public interface for
        * creating new instances.
        */
       static sptr make(size_t itemsize, char *address);
     };
 
-  } // namespace zmqblocks
+  } // namespace zeromq
 } // namespace gr
 
-#endif /* INCLUDED_ZMQBLOCKS_SINK_PUBSUB_H */
-
+#endif /* INCLUDED_ZEROMQ_SINK_PUBSUB_H */
@@ -18,39 +20,37 @@
        *
-       * To avoid accidental use of raw pointers, zmqblocks::sink_pubsub's
+       * To avoid accidental use of raw pointers, zeromq::sink_pubsub's
        * constructor is in a private implementation
@@ -18,39 +20,37 @@
        * constructor is in a private implementation
-       * class. zmqblocks::sink_pubsub::make is the public interface for
+       * class. zeromq::sink_pubsub::make is the public interface for
        * creating new instances.
        */
diff --git a/gr-zeromq/include/zmqblocks/sink_pushpull.h 
b/gr-zeromq/include/gnuradio/zeromq/sink_pushpull.h
similarity index 60%
rename from gr-zeromq/include/zmqblocks/sink_pushpull.h
rename to gr-zeromq/include/gnuradio/zeromq/sink_pushpull.h
index 394a0e9..7c6434f 100644
--- a/gr-zeromq/include/zmqblocks/sink_pushpull.h
+++ b/gr-zeromq/include/gnuradio/zeromq/sink_pushpull.h
@@ -1,9 +1,8 @@
 /* -*- c++ -*- */
 /* 
- * Copyright 2013 Institute for Theoretical Information Technology,
- *                RWTH Aachen University
- * 
- * Authors: Johannes Schmitz <address@hidden>
+ * Copyright 2013 Free Software Foundation, Inc.
+ *
+ * This file is part of GNU Radio.
  * 
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,39 +20,37 @@
  * Boston, MA 02110-1301, USA.
  */
 
+#ifndef INCLUDED_ZEROMQ_SINK_PUSHPULL_H
+#define INCLUDED_ZEROMQ_SINK_PUSHPULL_H
 
-#ifndef INCLUDED_ZMQBLOCKS_SINK_PUSHPULL_H
-#define INCLUDED_ZMQBLOCKS_SINK_PUSHPULL_H
-
-#include <zmqblocks/api.h>
+#include <gnuradio/zeromq/api.h>
 #include <gnuradio/sync_block.h>
 
 namespace gr {
-  namespace zmqblocks {
+  namespace zeromq {
 
     /*!
      * \brief <+description of block+>
-     * \ingroup zmqblocks
+     * \ingroup zeromq
      *
      */
-    class ZMQBLOCKS_API sink_pushpull : virtual public gr::sync_block
+    class ZEROMQ_API sink_pushpull : virtual public gr::sync_block
     {
-     public:
+    public:
       typedef boost::shared_ptr<sink_pushpull> sptr;
 
       /*!
-       * \brief Return a shared_ptr to a new instance of 
zmqblocks::sink_pushpull.
+       * \brief Return a shared_ptr to a new instance of zeromq::sink_pushpull.
        *
        * To avoid accidental use of raw pointers, zmqblocks::sink_pushpull's
        * constructor is in a private implementation
        * class. zmqblocks::sink_pushpull::make is the public interface for
        * creating new instances.
        */
       static sptr make(size_t itemsize, char *address);
     };
 
-  } // namespace zmqblocks
+  } // namespace zeromq
 } // namespace gr
 
-#endif /* INCLUDED_ZMQBLOCKS_SINK_PUSHPULL_H */
-
+#endif /* INCLUDED_ZEROMQ_SINK_PUSHPULL_H */
@@ -21,39 +20,37 @@
        *
-       * To avoid accidental use of raw pointers, zmqblocks::sink_pushpull's
+       * To avoid accidental use of raw pointers, zeromq::sink_pushpull's
        * constructor is in a private implementation
@@ -21,39 +20,37 @@
        * constructor is in a private implementation
-       * class. zmqblocks::sink_pushpull::make is the public interface for
+       * class. zeromq::sink_pushpull::make is the public interface for
        * creating new instances.
        */
diff --git a/gr-zeromq/include/zmqblocks/sink_reqrep.h 
b/gr-zeromq/include/gnuradio/zeromq/sink_reqrep.h
similarity index 60%
rename from gr-zeromq/include/zmqblocks/sink_reqrep.h
rename to gr-zeromq/include/gnuradio/zeromq/sink_reqrep.h
index 0ac2e03..bcecc8b 100644
--- a/gr-zeromq/include/zmqblocks/sink_reqrep.h
+++ b/gr-zeromq/include/gnuradio/zeromq/sink_reqrep.h
@@ -1,9 +1,8 @@
 /* -*- c++ -*- */
 /* 
- * Copyright 2013 Institute for Theoretical Information Technology,
- *                RWTH Aachen University
- * 
- * Authors: Johannes Schmitz <address@hidden>
+ * Copyright 2013 Free Software Foundation, Inc.
+ *
+ * This file is part of GNU Radio.
  * 
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,39 +20,37 @@
  * Boston, MA 02110-1301, USA.
  */
 
+#ifndef INCLUDED_ZEROMQ_SINK_REQREP_H
+#define INCLUDED_ZEROMQ_SINK_REQREP_H
 
-#ifndef INCLUDED_ZMQBLOCKS_SINK_REQREP_H
-#define INCLUDED_ZMQBLOCKS_SINK_REQREP_H
-
-#include <zmqblocks/api.h>
+#include <gnuradio/zeromq/api.h>
 #include <gnuradio/sync_block.h>
 
 namespace gr {
-  namespace zmqblocks {
+  namespace zeromq {
 
     /*!
      * \brief <+description of block+>
-     * \ingroup zmqblocks
+     * \ingroup zeromq
      *
      */
-    class ZMQBLOCKS_API sink_reqrep : virtual public gr::sync_block
+    class ZEROMQ_API sink_reqrep : virtual public gr::sync_block
     {
-     public:
+    public:
       typedef boost::shared_ptr<sink_reqrep> sptr;
-
+      
       /*!
-       * \brief Return a shared_ptr to a new instance of 
zmqblocks::sink_reqrep.
+       * \brief Return a shared_ptr to a new instance of zeromq::sink_reqrep.
        *
        * To avoid accidental use of raw pointers, zmqblocks::sink_reqrep's
        * constructor is in a private implementation
        * class. zmqblocks::sink_reqrep::make is the public interface for
        * creating new instances.
        */
       static sptr make(size_t itemsize, char *address);
     };
-
-  } // namespace zmqblocks
+    
+  } // namespace zeromq
 } // namespace gr
 
-#endif /* INCLUDED_ZMQBLOCKS_SINK_REQREP_H */
-
+#endif /* INCLUDED_ZEROMQ_SINK_REQREP_H */
@@ -21,39 +20,37 @@
        *
-       * To avoid accidental use of raw pointers, zmqblocks::sink_reqrep's
+       * To avoid accidental use of raw pointers, zeromq::sink_reqrep's
        * constructor is in a private implementation
@@ -21,39 +20,37 @@
        * constructor is in a private implementation
-       * class. zmqblocks::sink_reqrep::make is the public interface for
+       * class. zeromq::sink_reqrep::make is the public interface for
        * creating new instances.
        */
diff --git a/gr-zeromq/include/zmqblocks/sink_reqrep_nopoll.h 
b/gr-zeromq/include/gnuradio/zeromq/sink_reqrep_nopoll.h
similarity index 59%
rename from gr-zeromq/include/zmqblocks/sink_reqrep_nopoll.h
rename to gr-zeromq/include/gnuradio/zeromq/sink_reqrep_nopoll.h
index d7ec8f4..943e784 100644
--- a/gr-zeromq/include/zmqblocks/sink_reqrep_nopoll.h
+++ b/gr-zeromq/include/gnuradio/zeromq/sink_reqrep_nopoll.h
@@ -1,9 +1,8 @@
 /* -*- c++ -*- */
 /* 
- * Copyright 2013 Institute for Theoretical Information Technology,
- *                RWTH Aachen University
- * 
- * Authors: Johannes Schmitz <address@hidden>
+ * Copyright 2013 Free Software Foundation, Inc.
+ *
+ * This file is part of GNU Radio.
  * 
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,39 +20,37 @@
  * Boston, MA 02110-1301, USA.
  */
 
+#ifndef INCLUDED_ZEROMQ_SINK_REQREP_NOPOLL_H
+#define INCLUDED_ZEROMQ_SINK_REQREP_NOPOLL_H
 
-#ifndef INCLUDED_ZMQBLOCKS_SINK_REQREP_NOPOLL_H
-#define INCLUDED_ZMQBLOCKS_SINK_REQREP_NOPOLL_H
-
-#include <zmqblocks/api.h>
+#include <gnuradio/zeromq/api.h>
 #include <gnuradio/sync_block.h>
 
 namespace gr {
-  namespace zmqblocks {
+  namespace zeromq {
 
     /*!
      * \brief <+description of block+>
-     * \ingroup zmqblocks
+     * \ingroup zeromq
      *
      */
-    class ZMQBLOCKS_API sink_reqrep_nopoll : virtual public gr::sync_block
+    class ZEROMQ_API sink_reqrep_nopoll : virtual public gr::sync_block
     {
-     public:
+    public:
       typedef boost::shared_ptr<sink_reqrep_nopoll> sptr;
-
+      
       /*!
-       * \brief Return a shared_ptr to a new instance of 
zmqblocks::sink_reqrep_nopoll.
+       * \brief Return a shared_ptr to a new instance of 
zeromq::sink_reqrep_nopoll.
        *
-       * To avoid accidental use of raw pointers, 
zmqblocks::sink_reqrep_nopoll's
+       * To avoid accidental use of raw pointers, zeromq::sink_reqrep_nopoll's
        * constructor is in a private implementation
        * class. zmqblocks::sink_reqrep_nopoll::make is the public interface for
        * creating new instances.
        */
       static sptr make(size_t itemsize, char *address);
     };
-
-  } // namespace zmqblocks
+    
+  } // namespace zeromq
 } // namespace gr
 
-#endif /* INCLUDED_ZMQBLOCKS_SINK_REQREP_NOPOLL_H */
-
+#endif /* INCLUDED_ZEROMQ_SINK_REQREP_NOPOLL_H */
@@ -21,39 +20,37 @@
        * constructor is in a private implementation
-       * class. zmqblocks::sink_reqrep_nopoll::make is the public interface for
+       * class. zeromq::sink_reqrep_nopoll::make is the public interface for
        * creating new instances.
        */
diff --git a/gr-zeromq/include/zmqblocks/source_pushpull.h 
b/gr-zeromq/include/gnuradio/zeromq/source_pushpull.h
similarity index 60%
rename from gr-zeromq/include/zmqblocks/source_pushpull.h
rename to gr-zeromq/include/gnuradio/zeromq/source_pushpull.h
index de347db..076d7a0 100644
--- a/gr-zeromq/include/zmqblocks/source_pushpull.h
+++ b/gr-zeromq/include/gnuradio/zeromq/source_pushpull.h
@@ -1,9 +1,8 @@
 /* -*- c++ -*- */
 /* 
- * Copyright 2013 Institute for Theoretical Information Technology,
- *                RWTH Aachen University
- * 
- * Authors: Johannes Schmitz <address@hidden>
+ * Copyright 2013 Free Software Foundation, Inc.
+ *
+ * This file is part of GNU Radio.
  * 
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,39 +20,37 @@
  * Boston, MA 02110-1301, USA.
  */
 
+#ifndef INCLUDED_ZEROMQ_SOURCE_PUSHPULL_H
+#define INCLUDED_ZEROMQ_SOURCE_PUSHPULL_H
 
-#ifndef INCLUDED_ZMQBLOCKS_SOURCE_PUSHPULL_H
-#define INCLUDED_ZMQBLOCKS_SOURCE_PUSHPULL_H
-
-#include <zmqblocks/api.h>
+#include <gnuradio/zeromq/api.h>
 #include <gnuradio/sync_block.h>
 
 namespace gr {
-  namespace zmqblocks {
+  namespace zeromq {
 
     /*!
      * \brief <+description of block+>
-     * \ingroup zmqblocks
+     * \ingroup zeromq
      *
      */
-    class ZMQBLOCKS_API source_pushpull : virtual public gr::sync_block
+    class ZEROMQ_API source_pushpull : virtual public gr::sync_block
     {
-     public:
+    public:
       typedef boost::shared_ptr<source_pushpull> sptr;
 
       /*!
-       * \brief Return a shared_ptr to a new instance of 
zmqblocks::source_pushpull.
+       * \brief Return a shared_ptr to a new instance of 
zeromq::source_pushpull.
        *
        * To avoid accidental use of raw pointers, zmqblocks::source_pushpull's
        * constructor is in a private implementation
        * class. zmqblocks::source_pushpull::make is the public interface for
        * creating new instances.
        */
       static sptr make(size_t itemsize, char *address);
     };
 
-  } // namespace zmqblocks
+  } // namespace zeromq
 } // namespace gr
 
-#endif /* INCLUDED_ZMQBLOCKS_SOURCE_PUSHPULL_H */
-
+#endif /* INCLUDED_ZEROMQ_SOURCE_PUSHPULL_H */
@@ -21,39 +20,37 @@
zeromq::source_pushpull.
        *
-       * To avoid accidental use of raw pointers, zmqblocks::source_pushpull's
+       * To avoid accidental use of raw pointers, zeromq::source_pushpull's
        * constructor is in a private implementation
@@ -21,39 +20,37 @@
        * constructor is in a private implementation
-       * class. zmqblocks::source_pushpull::make is the public interface for
+       * class. zeromq::source_pushpull::make is the public interface for
        * creating new instances.
        */
diff --git a/gr-zeromq/include/zmqblocks/source_reqrep.h 
b/gr-zeromq/include/gnuradio/zeromq/source_reqrep.h
similarity index 60%
rename from gr-zeromq/include/zmqblocks/source_reqrep.h
rename to gr-zeromq/include/gnuradio/zeromq/source_reqrep.h
index 8c7b1ee..a6c3fe6 100644
--- a/gr-zeromq/include/zmqblocks/source_reqrep.h
+++ b/gr-zeromq/include/gnuradio/zeromq/source_reqrep.h
@@ -1,10 +1,9 @@
 /* -*- c++ -*- */
 /* 
- * Copyright 2013 Institute for Theoretical Information Technology,
- *                RWTH Aachen University
- * 
- * Authors: Johannes Schmitz <address@hidden>
- * 
+ * Copyright 2013 Free Software Foundation, Inc.
+ *
+ * This file is part of GNU Radio.
+ *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3, or (at your option)
@@ -21,39 +20,37 @@
  * Boston, MA 02110-1301, USA.
  */
 
+#ifndef INCLUDED_ZEROMQ_SOURCE_REQREP_H
+#define INCLUDED_ZEROMQ_SOURCE_REQREP_H
 
-#ifndef INCLUDED_ZMQBLOCKS_SOURCE_REQREP_H
-#define INCLUDED_ZMQBLOCKS_SOURCE_REQREP_H
-
-#include <zmqblocks/api.h>
+#include <gnuradio/zeromq/api.h>
 #include <gnuradio/sync_block.h>
 
 namespace gr {
-  namespace zmqblocks {
+  namespace zeromq {
 
     /*!
      * \brief <+description of block+>
-     * \ingroup zmqblocks
+     * \ingroup zeromq
      *
      */
-    class ZMQBLOCKS_API source_reqrep : virtual public gr::sync_block
+    class ZEROMQ_API source_reqrep : virtual public gr::sync_block
     {
-     public:
+    public:
       typedef boost::shared_ptr<source_reqrep> sptr;
 
       /*!
-       * \brief Return a shared_ptr to a new instance of 
zmqblocks::source_reqrep.
+       * \brief Return a shared_ptr to a new instance of zeromq::source_reqrep.
        *
        * To avoid accidental use of raw pointers, zmqblocks::source_reqrep's
        * constructor is in a private implementation
        * class. zmqblocks::source_reqrep::make is the public interface for
        * creating new instances.
        */
       static sptr make(size_t itemsize, char *address);
     };
 
-  } // namespace zmqblocks
+  } // namespace zeromq
 } // namespace gr
 
-#endif /* INCLUDED_ZMQBLOCKS_SOURCE_REQREP_H */
-
+#endif /* INCLUDED_ZEROMQ_SOURCE_REQREP_H */
@@ -21,39 +20,37 @@
        *
-       * To avoid accidental use of raw pointers, zmqblocks::source_reqrep's
+       * To avoid accidental use of raw pointers, zeromq::source_reqrep's
        * constructor is in a private implementation
@@ -21,39 +20,37 @@
        * constructor is in a private implementation
-       * class. zmqblocks::source_reqrep::make is the public interface for
+       * class. zeromq::source_reqrep::make is the public interface for
        * creating new instances.
        */